/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import springfox.documentation.builders.RequestHandlerSelectors;
import springfox.documentation.service.ApiInfo;
import springfox.documentation.service.Contact;
import springfox.documentation.spi.DocumentationType;
import springfox.documentation.spring.web.paths.RelativePathProvider;
import springfox.documentation.spring.web.plugins.Docket;
import springfox.documentation.swagger2.annotations.EnableSwagger2;

import javax.servlet.ServletContext;
import java.util.ArrayList;

/**
 * Swagger Config for API self documentation.
 *
 * @author moses AT doraventures DOT com

 */
@Configuration
@EnableSwagger2
public class SwaggerConfig {

  private final ServletContext servletContext;
  private final String baseEndpoint;

  @Autowired
  public SwaggerConfig(@Value("${osmhhandler.baseEndpoint}") String baseEndpoint, ServletContext servletContext) {
    this.baseEndpoint = baseEndpoint;
    this.servletContext = servletContext;
  }

  private static ApiInfo metaData() {

    Contact contact = new Contact("Cessda PaSC", "https://www.cessda.eu/", "support@cessda.eu");
    String version = SwaggerConfig.class.getPackage().getImplementationVersion();

    return new ApiInfo(
        "CDC OSMH Handler [OAI-PMH - NESSTAR]",
        "CDC OSMH repository handler for harvesting OAI-PMH metadata format specifically for NESSTAR repositories",
        version,
        "https://www.ukdataservice.ac.uk/conditions",
        contact,
        "Apache License Version 2.0",
        "https://www.apache.org/licenses/LICENSE-2.0",
        new ArrayList<>());
  }

  @Bean
  public Docket api() {
    return new Docket(DocumentationType.SWAGGER_2)
        .select()
        .apis(RequestHandlerSelectors.basePackage("eu.cessda.pasc.osmhhandler.nesstar.controller"))
        .build()
        .useDefaultResponseMessages(false)
        .pathProvider(new RelativePathProvider(servletContext) {
          @Override
          public String getApplicationBasePath() {
            return baseEndpoint;
          }
        })
        .apiInfo(SwaggerConfig.metaData());
  }
}