/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.controller;

import eu.cessda.pasc.osmhhandler.nesstar.exception.HandlerException;
import eu.cessda.pasc.osmhhandler.nesstar.models.cmmstudy.CMMStudy;
import eu.cessda.pasc.osmhhandler.nesstar.service.GetRecordService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import static eu.cessda.pasc.osmhhandler.nesstar.helpers.HandlerConstants.*;

/**
 * Controller to handle request for getting a remote Record.
 *
 * @author moses AT doraventures DOT com
 */
@Api(value = "GetRecord", tags = {"GetRecord"})
@ApiResponses(value = {
        @ApiResponse(code = 400, message = BAD_REQUEST, response = ErrorMessage.class),
        @ApiResponse(code = 404, message = NOT_FOUND, response = ErrorMessage.class),
        @ApiResponse(code = 500, message = SYSTEM_ERROR, response = ErrorMessage.class)
})
@RestController
@RequestMapping("v0/GetRecord")
@Slf4j
public class GetRecordController {

    private static final String GETS_A_RECORD = "Gets a Record with the given identifier";

    private final GetRecordService getRecordService;

    @Autowired
    public GetRecordController(GetRecordService getRecordService) {
        this.getRecordService = getRecordService;
    }

    private static String decodeStudyNumber(String encodedStudyNumber) {
        return encodedStudyNumber.replace("_dt_", ".")
                .replace("_sl_", "/")
                .replace("_cl_", ":");
    }

    @GetMapping(value = "/CMMStudy/{encodedStudyId}")
    @ApiOperation(value = GETS_A_RECORD, response = CMMStudy.class, produces = MediaType.APPLICATION_JSON_VALUE, consumes = MediaType.APPLICATION_JSON_VALUE)
    public ResponseEntity<CMMStudy> getRecord(
            @PathVariable String encodedStudyId,
            @RequestParam("Repository") String repository,
            @RequestParam(required = false) String defaultLanguage) throws HandlerException {
        String studyId = decodeStudyNumber(encodedStudyId);
        CMMStudy cmmStudy = getRecordService.getRecord(repository, studyId, defaultLanguage);
        return ResponseEntity.ok(cmmStudy);
    }
}
