/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.controller;

import eu.cessda.pasc.osmhhandler.nesstar.exception.HandlerException;
import eu.cessda.pasc.osmhhandler.nesstar.models.response.RecordHeader;
import eu.cessda.pasc.osmhhandler.nesstar.service.ListRecordHeadersServiceImpl;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

import static eu.cessda.pasc.osmhhandler.nesstar.helpers.HandlerConstants.SYSTEM_ERROR;

/**
 * Controller to handle request for Record Headers.
 *
 * @author moses AT doraventures DOT com
 */
@RestController
@RequestMapping("v0/ListRecordHeaders")
@Api(tags = "ListRecordHeaders")
@ApiResponses(@ApiResponse(code = 500, message = SYSTEM_ERROR, response = ErrorMessage.class))
@Slf4j
public class ListRecordHeadersController {

    private static final String GETS_A_LIST_OF_ALL_SUPPORTED_RECORD_TYPES = "Gets a list of all supported record types";

    private final ListRecordHeadersServiceImpl listRecordHeadersService;

    @Autowired
    public ListRecordHeadersController(ListRecordHeadersServiceImpl listRecordHeadersService) {
        this.listRecordHeadersService = listRecordHeadersService;
    }

    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = GETS_A_LIST_OF_ALL_SUPPORTED_RECORD_TYPES)
    public ResponseEntity<List<RecordHeader>> getRecordHeaders(@RequestParam("Repository") String repository) throws HandlerException {
        List<RecordHeader> recordHeaders = listRecordHeadersService.getRecordHeaders(repository);
        return ResponseEntity.ok(recordHeaders);
    }
}
