/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.controller;

import eu.cessda.pasc.osmhhandler.nesstar.service.APISupportedService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.MediaType;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

import java.util.List;

/**
 * Controller to handle request for supported Record Types per supported API version.
 *
 * @author moses AT doraventures DOT com
 */
@RestController
@RequestMapping("v0/ListSupportedRecordTypes")
@Api(value = "ListSupportedRecordTypes", tags = {"ListSupportedRecordTypes"})
@Slf4j
public class ListSupportedRecordTypesController {

    private static final String GETS_A_LIST_OF_SUPPORTED_RECORD_TYPES = "Gets a list of Supported Record Types.";

    private final APISupportedService apiSupportedService;

    @Autowired
    public ListSupportedRecordTypesController(APISupportedService apiSupportedService) {
        this.apiSupportedService = apiSupportedService;
    }

    @GetMapping(produces = MediaType.APPLICATION_JSON_VALUE)
    @ApiOperation(value = GETS_A_LIST_OF_SUPPORTED_RECORD_TYPES)
    public ResponseEntity<List<String>> getSupportedRecordTypes() {
        return new ResponseEntity<>(apiSupportedService.getSupportedRecordTypes(), HttpStatus.OK);
    }
}