/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.helpers;

import lombok.experimental.UtilityClass;
import org.jdom2.Namespace;

/**
 * OaiPmh related attributes and element Constants
 *
 * @author moses AT doraventures DOT com
 */
@UtilityClass
public class OaiPmhConstants {

  // Namespaces
  static final Namespace OAI_NS = Namespace.getNamespace("oai", "http://www.openarchives.org/OAI/2.0/");
  static final Namespace NESSTAR_NS = Namespace.getNamespace("ddi", "http://www.icpsr.umich.edu/DDI");
  static final Namespace[] OAI_AND_DDI_NS = {OAI_NS, NESSTAR_NS};

  // General Paths
  static final String IDENTIFIER_XPATH = "//oai:header/oai:identifier[1]";
  static final String RECORD_STATUS_XPATH = "//oai:header/@status";
  static final String LAST_MODIFIED_DATE_XPATH = "//oai:header/oai:datestamp[1]";
  static final String ERROR_PATH = "//oai:error";

  // Codebook Paths
  static final String RECORD_DEFAULT_LANGUAGE = "//ddi:codeBook/@xml-lang"; // Nesstar with "-"

  /**
   * Closest for Nesstar based on CMM mapping doc but the above existing one for ddi2.5 seems to be present in Nesstar
   * static final String YEAR_OF_PUB_XPATH = "//ddi:codeBook/docDscr/citation/prodStmt/prodDate[1]/@date";
   */
  static final String YEAR_OF_PUB_XPATH = "//ddi:codeBook/stdyDscr/citation/distStmt/distDate[1]/@date";
  static final String ABSTRACT_XPATH = "//ddi:codeBook/stdyDscr/stdyInfo/abstract";
  static final String TITLE_XPATH = "//ddi:codeBook/stdyDscr/citation/titlStmt/titl";
  static final String PAR_TITLE_XPATH = "//ddi:codeBook/stdyDscr/citation/titlStmt/parTitl";
  static final String STUDY_URL_XPATH = "//ddi:codeBook/stdyDscr/dataAccs/setAvail/accsPlac";
  // PID path missing for most nesstar repos. Available in FORS but:
  //  -No agency
  //  -Only element freetext value.
  static final String PID_STUDY_XPATH = "//ddi:codeBook/stdyDscr/citation/titlStmt/IDNo"; // use @agency instead?
  static final String CREATORS_XPATH = "//ddi:codeBook/stdyDscr/citation/rspStmt/AuthEnty";
  static final String DATA_RESTRCTN_XPATH = "//ddi:codeBook/stdyDscr/dataAccs/useStmt/restrctn";
  static final String DATA_COLLECTION_PERIODS_PATH = "//ddi:codeBook/stdyDscr/stdyInfo/sumDscr/collDate";
  static final String CLASSIFICATIONS_XPATH = "//ddi:codeBook/stdyDscr/stdyInfo/subject/topcClas";
  static final String KEYWORDS_XPATH = "//ddi:codeBook/stdyDscr/stdyInfo/subject/keyword";
  static final String TYPE_OF_TIME_METHOD_XPATH = "//ddi:codeBook/stdyDscr/method/dataColl/timeMeth";
  static final String STUDY_AREA_COUNTRIES_XPATH = "//ddi:codeBook/stdyDscr/stdyInfo/sumDscr/nation";
  static final String UNIT_TYPE_XPATH = "//ddi:codeBook/stdyDscr/stdyInfo/sumDscr/anlyUnit";
  static final String PUBLISHER_XPATH = "//ddi:codeBook/docDscr/citation/prodStmt/producer";
  static final String DISTRIBUTOR_XPATH = "//ddi:codeBook/stdyDscr/citation/distStmt/distrbtr";
  static final String SAMPLING_XPATH = "//ddi:codeBook/stdyDscr/method/dataColl/sampProc";
  static final String TYPE_OF_MODE_OF_COLLECTION_XPATH = "//ddi:codeBook/stdyDscr/method/dataColl/collMode";

  // Elements
  static final String LANG_ATTR = "lang";
  public static final String IDENTIFIER_ELEMENT = "identifier";
  public static final String DATESTAMP_ELEMENT = "datestamp";
  public static final String HEADER_ELEMENT = "header";
  public static final String RESUMPTION_TOKEN_ELEMENT = "resumptionToken";

  // Attributes
  static final String DATE_ATTR = "date";
  static final String END_ATTR = "end";
  static final String START_ATTR = "start";
  static final String SINGLE_ATTR = "single";
  static final String EVENT_ATTR = "event";
  static final String CODE_ATTR = "code";
  static final String CREATOR_AFFILIATION_ATTR = "affiliation";
  static final String VOCAB_ATTR = "vocab";
  static final String VOCAB_URI_ATTR = "vocabURI";
  static final String ID_ATTR = "ID";
  static final String ABBR_ATTR = "abbr";
  static final String AGENCY_ATTR = "agency";
  static final String CONCEPT_EL = "concept";
  static final String URI_ATTR = "URI";
  public static final String COMPLETE_LIST_SIZE_ATTR = "completeListSize";
  static final String OAI_PMH = "OAI-PMH";
  static final String ERROR = "error";

  // URL Paths tokens
  static final String VERB_PARAM_KEY = "verb";
  static final String METADATA_PREFIX_PARAM_KEY = "metadataPrefix";
  static final String SET_SPEC_PARAM_KEY = "set";
  static final String IDENTIFIER_PARAM_KEY = IDENTIFIER_ELEMENT;
  static final String RESUMPTION_TOKEN_KEY = RESUMPTION_TOKEN_ELEMENT;
  static final String LIST_IDENTIFIERS_VALUE = "ListIdentifiers";
  static final String GET_RECORD_VALUE = "GetRecord";

  static final String LIST_RECORD_HEADERS_URL_TEMPLATE = "%s?%s=%s&%s=%s";
  static final String LIST_RECORD_HEADERS_PER_SET_URL_TEMPLATE = "%s?%s=%s&%s=%s&%s=%s";
  static final String GET_RECORD_URL_TEMPLATE = "%s?%s=%s&%s=%s&%s=%s";
}
