/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.helpers;

import eu.cessda.pasc.osmhhandler.nesstar.exception.OaiPmhException;
import lombok.experimental.UtilityClass;
import org.jdom2.Document;
import org.jdom2.Element;
import org.jdom2.xpath.XPathFactory;

import java.util.Optional;

/**
 * GET Record Response Validator.
 *
 * @author moses AT doraventures DOT com
 */
@UtilityClass
public class RecordResponseValidator {

  /**
   * Checks if the record has an <error> element.
   *
   * @param document the document to map to.
   * @param xFactory the Path Factory.
   */
  public static void validateResponse(Document document, XPathFactory xFactory) throws OaiPmhException {

    final Optional<Element> optionalElement = DocElementParser.getFirstElement(document, xFactory, OaiPmhConstants.ERROR_PATH);

    if (optionalElement.isPresent()) {
      final Element element = optionalElement.get();
      if (element.getText() != null && !element.getText().trim().isEmpty()) {
        throw new OaiPmhException(OaiPmhException.Code.valueOf(element.getAttributeValue(OaiPmhConstants.CODE_ATTR)), element.getText());
      } else {
        throw new OaiPmhException(OaiPmhException.Code.valueOf(element.getAttributeValue(OaiPmhConstants.CODE_ATTR)));
      }
    }
  }
}