/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.helpers;

import lombok.experimental.UtilityClass;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.time.DateUtils;

import java.text.ParseException;
import java.time.LocalDateTime;
import java.time.ZoneOffset;
import java.util.Optional;

import static eu.cessda.pasc.osmhhandler.nesstar.helpers.HandlerConstants.EXPECTED_DATE_FORMATS;

@Slf4j
@UtilityClass
class TimeUtility {

  /**
   * Attempts to parse the date string into a LocalDateTime using multiple expected date formats.
   *
   * @param dateString to parse as a LocalDateTime.
   * @return a {@link LocalDateTime} representing the date string
   * @throws ParseException           if the date string cannot be parsed
   * @throws IllegalArgumentException if the date string is {@code null}
   */
  @SuppressWarnings("JdkObsolete")
  static LocalDateTime getLocalDateTime(String dateString) throws ParseException {
    return DateUtils.parseDate(dateString, EXPECTED_DATE_FORMATS).toInstant()
            .atOffset(ZoneOffset.UTC)
            .toLocalDateTime();
  }

  static Optional<Integer> dataCollYearDateFunction(String dateString) {
    try {
      var localDateTime = TimeUtility.getLocalDateTime(dateString);
      return Optional.of(localDateTime.getYear());
    } catch (ParseException e) {
      log.warn(e.toString());
      return Optional.empty();
    }
  }
}