/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.controller;

import com.fasterxml.jackson.databind.ObjectMapper;
import eu.cessda.pasc.osmhhandler.nesstar.configuration.HandlerConfigurationProperties;
import eu.cessda.pasc.osmhhandler.nesstar.service.APISupportedService;
import eu.cessda.pasc.osmhhandler.nesstar.service.APISupportedServiceImpl;
import org.hamcrest.core.IsNull;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.autoconfigure.web.servlet.WebMvcTest;
import org.springframework.boot.test.mock.mockito.MockBean;
import org.springframework.boot.test.mock.mockito.SpyBean;
import org.springframework.context.annotation.Import;
import org.springframework.http.MediaType;
import org.springframework.security.test.context.support.WithMockUser;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit4.SpringRunner;
import org.springframework.test.web.servlet.MockMvc;

import java.util.List;

import static org.mockito.ArgumentMatchers.any;
import static org.mockito.BDDMockito.given;
import static org.springframework.test.web.servlet.request.MockMvcRequestBuilders.get;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.content;
import static org.springframework.test.web.servlet.result.MockMvcResultMatchers.status;

/**
 * MockMVC tests for the Controller
 *
 * @author moses AT doraventures DOT com

 */
@RunWith(SpringRunner.class)
@WebMvcTest(ListSupportedRecordTypesController.class)
@Import({APISupportedServiceImpl.class, HandlerConfigurationProperties.class})
@ActiveProfiles("test")
@WithMockUser(username = "user")
public class ListSupportedRecordTypesControllerTest {
  private static final ObjectMapper MAPPER = new ObjectMapper();

  @MockBean
  APISupportedService apiSupportedService;

  @SpyBean
  ObjectMapper objectMapper;

  @Autowired
  private MockMvc mockMvc;

  @Test
  public void shouldReturnTheSupportedRecordTypesSuccessfully() throws Exception {

    // Given
    String expectedRecords = "[\"StudyGroup\", \"Study\", \"Variable\", \"CMM\", \"Question\"]";

    given(this.apiSupportedService.isSupportedVersion(any()))
            .willReturn(true);

    given(this.apiSupportedService.getSupportedRecordTypes())
            .willReturn(List.of("Study", "StudyGroup", "Variable", "Question", "CMM"));

    // When
    this.mockMvc.perform(get("/v0/ListSupportedRecordTypes").accept(MediaType.APPLICATION_JSON_VALUE))

            // Then
            .andExpect(status().isOk())
            .andExpect(status().reason(new IsNull<>()))
            .andExpect(content().json(expectedRecords));
  }

  @Test
  public void shouldReturnErrorMessageForUnsupportedAPI() throws Exception {

    // When
    this.mockMvc.perform(get("/v1/ListSupportedRecordTypes").accept(MediaType.APPLICATION_JSON_VALUE))

            // Then
            .andExpect(status().isNotFound())
            .andExpect(status().reason(new IsNull<>()));
  }

  @Test
  public void shouldReturnErrorMessageForInvalidPath() throws Exception {
    // When
      this.mockMvc.perform(get("/v0/ListSupportedRecordTypes/anythinelse").accept(MediaType.APPLICATION_JSON_VALUE))

              // Then
              .andExpect(status().isNotFound())
              .andExpect(status().reason(new IsNull<>()));
  }
}
