/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.dao;

import com.pgssoft.httpclient.HttpClientMock;
import eu.cessda.pasc.osmhhandler.nesstar.exception.HandlerException;
import lombok.extern.slf4j.Slf4j;
import org.junit.Test;

import java.io.IOException;
import java.io.InputStream;
import java.nio.charset.StandardCharsets;

import static org.assertj.core.api.BDDAssertions.then;

/**
 * @author moses AT doraventures DOT com
 */
@Slf4j
public class ListRecordHeadersDaoImplTest {

    private final HttpClientMock httpClient = new HttpClientMock();

    @Test
    public void shouldReturnXmlPayloadOfRecordHeadersFromRemoteRepository() throws HandlerException, IOException {

        // Given
        String fullListRecordsRepoUrl = "https://nesstar2.adp.fdv.uni-lj.si/oai-pmh?verb=ListIdentifiers&metadataPrefix=oai_ddi";

        httpClient.onGet(fullListRecordsRepoUrl).doReturn(fullListRecordsRepoUrl, StandardCharsets.UTF_8);

        // When
        ListRecordHeadersDao listRecordHeadersDao = new ListRecordHeadersDaoImpl(httpClient);
        try (InputStream inputStream = listRecordHeadersDao.listRecordHeaders(fullListRecordsRepoUrl)) {
            String recordHeadersXML = new String(inputStream.readAllBytes(), StandardCharsets.UTF_8);
            log.info("Actual: {}", recordHeadersXML);

            then(recordHeadersXML).isNotNull();
            then(recordHeadersXML).isNotEmpty();
            then(recordHeadersXML).contains(fullListRecordsRepoUrl);
        }
    }

    @Test
    public void shouldReturnXmlPayloadOfGivenSpecSetRecordHeadersFromRemoteRepository() throws HandlerException, IOException {

        // Given
        String fullListRecordsRepoUrl = "http://fors-nesstar.unil.ch/oai-pmh?verb=ListIdentifiers&metadataPrefix=oai_ddi&set=made_up_spec_val";

        httpClient.onGet(fullListRecordsRepoUrl).doReturn(fullListRecordsRepoUrl, StandardCharsets.UTF_8);

        // When
        ListRecordHeadersDao listRecordHeadersDao = new ListRecordHeadersDaoImpl(httpClient);
        try (InputStream inputStream = listRecordHeadersDao.listRecordHeaders(fullListRecordsRepoUrl)) {
            String recordHeadersXML = new String(inputStream.readAllBytes(), StandardCharsets.UTF_8);

            log.info("Actual: {}", recordHeadersXML);

            then(recordHeadersXML).isNotNull();
            then(recordHeadersXML).isNotEmpty();
            then(recordHeadersXML).contains(fullListRecordsRepoUrl);
        }
    }
}