/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.helpers;

import eu.cessda.pasc.osmhhandler.nesstar.configuration.HandlerConfigurationProperties;
import eu.cessda.pasc.osmhhandler.nesstar.exception.HandlerException;
import eu.cessda.pasc.osmhhandler.nesstar.models.configuration.Repo;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.test.context.SpringBootTest;
import org.springframework.test.context.ActiveProfiles;
import org.springframework.test.context.junit4.SpringRunner;

import static eu.cessda.pasc.osmhhandler.nesstar.helpers.OaiPmhHelpers.buildGetStudyFullUrl;
import static eu.cessda.pasc.osmhhandler.nesstar.helpers.OaiPmhHelpers.getMetadataPrefix;
import static org.assertj.core.api.BDDAssertions.then;

/**
 * Test class for {@link OaiPmhHelpers}
 *
 * @author moses AT doraventures DOT com
 */
@RunWith(SpringRunner.class)
@SpringBootTest
@ActiveProfiles("test")
public class OaiPmhHelpersTest {


    @Autowired
    private HandlerConfigurationProperties handlerConfigurationProperties;

    private static String getStudyURLForEndpoint(String endpoint) {
        var repo = new Repo();
        repo.setUrl(endpoint);
        repo.setPreferredMetadataParam("oai_ddi");
        return buildGetStudyFullUrl(repo, "15454");
    }

    @Test
    public void ShouldReturnFullGetRecordUrlForAGivenSP() {

        // Given
        String fsdEndpoint = "http://fors-nesstar.unil.ch/oai-pmh";
        String expectedReqUrl = "http://fors-nesstar.unil.ch/oai-pmh?verb=GetRecord&identifier=15454&metadataPrefix=oai_ddi";

        // When
        String builtUrl = getStudyURLForEndpoint(fsdEndpoint);

        then(builtUrl).isEqualTo(expectedReqUrl);
    }

    @Test
  public void ShouldAppendMetaDataPrefixForGivenRepoURL() {

        // Given
        String fsdEndpoint = "https://nesstar2.adp.fdv.uni-lj.si/oai-pmh";
        String expectedReqUrl = "https://nesstar2.adp.fdv.uni-lj.si/oai-pmh?verb=GetRecord&identifier=15454&metadataPrefix=oai_ddi";

        // When
        String builtUrl = getStudyURLForEndpoint(fsdEndpoint);

        then(builtUrl).isEqualTo(expectedReqUrl);
    }

    @Test(expected = HandlerException.class)
    public void ShouldThrowExceptionForANonConfiguredRepo() throws HandlerException {
        // when
        getMetadataPrefix("http://services.inthe.future/v0/oai", handlerConfigurationProperties.getOaiPmh());
    }

}