/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
/*
  # Copyright CESSDA ERIC 2017-2019
  #
  # Licensed under the Apache License, Version 2.0 (the "License"); you may not
  # use this file except in compliance with the License.
  # You may obtain a copy of the License at
  # http://www.apache.org/licenses/LICENSE-2.0
  <p>
  # Unless required by applicable law or agreed to in writing, software
  # distributed under the License is distributed on an "AS IS" BASIS,
  # WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  # See the License for the specific language governing permissions and
  # limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.helpers;

import org.junit.Assert;
import org.junit.BeforeClass;
import org.junit.Test;
import org.junit.runner.RunWith;
import org.junit.runners.Parameterized;

import java.util.*;

/**
 * Parameterised test for various date possibilities
 *
 * @author moses AT doraventures DOT com
 */
@RunWith(Parameterized.class)
public class TimeUtilDateExtractionParameterisedTest {

    private final String fInput;
    private final int fExpected;

    public TimeUtilDateExtractionParameterisedTest(String fInput, int fExpected) {
        this.fInput = fInput;
        this.fExpected = fExpected;
    }

    @BeforeClass
    public static void SetUpClass() {
        TimeZone.setDefault(TimeZone.getTimeZone("UTC"));
    }

    // variable labels from junit v4.12
    @Parameterized.Parameters(name = "{index}: YearDateExtraction For date ({0}) expected to be: ({1})")
    public static Collection<Object[]> data() {

        List<Object[]> testData = new ArrayList<>();
        testData.add(new Object[]{"1982-01-01T00:00:00Z", 1982}); // INPUT, EXPECTED_RESULT
        testData.add(new Object[]{"1915-01-01", 1915});
        testData.add(new Object[]{"1915-01", 1915});
        testData.add(new Object[]{"1915", 1915});
        testData.add(new Object[]{"1955", 1955});
        testData.add(new Object[]{"2020", 2020});

        return testData;
    }

    @Test
    public void shouldExtractDataCollYearDateFunction() {

        // When
        Optional<Integer> actualYearDate = TimeUtility.dataCollYearDateFunction(fInput);

        // Then
        Assert.assertTrue(actualYearDate.isPresent());
        Assert.assertEquals(fExpected, actualYearDate.get().intValue());
    }
}