/*
 * Copyright © 2017-2021 CESSDA ERIC (support@cessda.eu)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package eu.cessda.pasc.osmhhandler.nesstar.helpers;

import org.junit.Assert;
import org.junit.Test;

import java.text.ParseException;
import java.util.Optional;

import static org.assertj.core.api.BDDAssertions.then;


/**
 * @author moses AT doraventures DOT com

 */
public class TimeUtilityTest {


  @Test
  public void shouldReturnExpectedDateValue() throws ParseException {

    // Given
    var localDateTime = TimeUtility.getLocalDateTime("2018-03-20");

    // When
    then(localDateTime.toString()).isEqualToIgnoringCase("2018-03-20T00:00");
  }

  // String format yyyy-MM-dd'T'HH:mm:ssZ
  @Test
  public void shouldReturnExpectedDateValueForNesstarDateFormats() throws ParseException {

    // Given
    String[] dates = {"2015-05-04T22:55:30+0000", "2015-05-04T22:20:10+0000", "2016-03-29T13:15:15+0000"};

    // When
    for (String date : dates) {
      var localDateTime = TimeUtility.getLocalDateTime(date);
      String expectedParsedDateString = date.substring(0, date.length() - 5);
      then(localDateTime.toString()).isEqualToIgnoringCase(expectedParsedDateString);
    }
  }

  @Test(expected = ParseException.class)
  public void shouldReturnMissingForInvalidDateValue() throws ParseException {
    // Given
    TimeUtility.getLocalDateTime("invalid-date-string");
  }

  @Test
  public void shouldExtractDataCollYearDateFunction() {

    // Given
    final int expected = 1982;
    final String rawDate = "1982-01-01T00:00:00Z";

    // When
    Optional<Integer> actualYearDate = TimeUtility.dataCollYearDateFunction(rawDate);

    Assert.assertTrue(actualYearDate.isPresent());
    Assert.assertEquals(expected, actualYearDate.get().intValue());
  }
}